Thanks for your interest in pymad!

This project is maintained on a best effort basis.  PRs with tests are the best way to make improvements, PRs without tests will be accepted if they look reasonable.  Issue reports are unlikely to be resolved without your assistance.

